@@ -1,11 +1,20 @@
+/*
+ * Copyright (c) 2023 - 2025 Chair for Design Automation, TUM
+ * Copyright (c) 2025 Munich Quantum Software Company GmbH
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: MIT
+ *
+ * Licensed under the MIT License
+ */
+
 /*
  * This file is part of the MQT DD Package which is released under the MIT
  * license. See file README.md or go to
  * https://www.cda.cit.tum.de/research/quantum_dd/ for more information.
  */
 
-#ifndef DD_PACKAGE_COMPLEXTABLE_HPP
-#define DD_PACKAGE_COMPLEXTABLE_HPP
+#pragma once
 
 #include "Definitions.hpp"
 
@@ -639,4 +648,3 @@ private:
   }
 };
 } // namespace dd
-#endif // DD_PACKAGE_COMPLEXTABLE_HPP
